Description: Pychemkin HTML Report.

# Pychemkin Report

# Reaction System

Temperature: 1000.0K

Reaction | Forward Reaction Coeff. (kf) | Backward Reaction Coeff. (kb)
--- | --- | ---
C + H ⇄ CH | 2.1428615605e+12 | 6.31632072164
CH + 2CH3 ⇄ C3H7 | 5.15914857193e+13 | 5.36008273111e-11
2OH → HO2 + H | 4.84487375593e+12 | N/A
CH3 → 2H + CH | 1.50354844794e+13 | N/A
O2 + CH → HO2 + C | 6.83222463525e+13 | N/A

# Reaction system concentrations

Specie | Initial Concentration | Final Concentration
--- | --- | ---
H | 1.0 | 0.8264880777737722
OH | 1.0 | 0.17111846470080036
O2 | 1.0 | -5.591792985692733e-14
HO2 | 1.0 | 2.414440767649653
C | 1.0 | 0.5955392942198859
CH | 1.0 | 1.5168976163677534
CH3 | 1.0 | 0.00011179731876490732
C3H7 | 1.0 | 1.295817097364533

System hasn't reached equilibrium yet

# Visualization

## Reaction Time Series

## Reaction Network

This diagram shows how species in the reaction system relate to one another. The size of the annulus around the species name scales linearly with the concentration of the species at a given timepoint. Red bubbles indicate that the concentration is decreasing and teal bubbles indicate that the concentration is increasing. Species that react with one another (including reverse reactions) are connected by blue ribbons. The width of the ribbon is scaled by the logarithm of the reaction rate coefficient (forward coefficient for the forward reaction and backward coefficient for the backward reaction, if applicable.)